@@ -9,8 +9,8 @@ def setSingleProcess(ProcName):
     """
     Set process name only if not exists.
     """
-    proclist = commands.getoutput('ps -A')
-    if ProcName in proclist:
+    procString = commands.getoutput('ps -A | grep -E '+ProcName+'$')
+    if procString!="":
         return False
     else:
         setproctitle(ProcName)
